{# To be used in html_sidebars #}
<p class="insipid-icon" style="text-align: center; font-weight: bold;">
  <a class="reference internal" href="{{ pathto(master_doc) }}">{% include 'icons/home.svg' %}
{{ project|e }}</a>
</p>
