{# NB: "click" event handler is added via JavaScript #}
            <button id="fullscreen-button" type="button" aria-hidden="true">
              <span class="enable">
                {% include 'icons/fullscreen-enable.svg' %}
              </span>
              <span class="disable">
                {% include 'icons/fullscreen-disable.svg' %}
              </span>
            </button>
