{% extends "layout.html" %}


{% block body %}
{%- if theme_breadcrumbs|tobool %}
<nav class="crumbs">
  <ul>
    {%- block rootrellink %}
    <li><a href="{{ pathto(master_doc) }}" aria-label="{{ docstitle|e }}">{% include 'icons/home.svg' %}</a>{{ reldelim1 }}</li>
    {%- endblock %}
    {%- for parent in parents %}
    <li><a href="{{ parent.link|e }}">{{ parent.title }}</a>{{ reldelim1 }}</li>
    {%- endfor %}
    <li><a href="{{ link|e }}">{{ title }}</a></li>
    {%- block relbaritems %} {% endblock %}
  </ul>
</nav>
{%- endif %}
{{ body }}
{%- endblock %}
