"""Module docstring."""


def a_very_useful_function(one, two, three, four=3):
    """This is one of the most useful functions.

    :param str one: First argument
    :param int two: Second argument
    :param float three: Third argument
    :param four: Fourth argument
    :type four: integer or None

    """


class TheBestClass:
    """This is a class."""

    def __init__(self, value=4):
        """This is the constructor."""

    def multiplicate(self, factor):
        """Scale the thing."""
